@@ -31,7 +31,7 @@ import (
 )
 
 const (
-	version             = "0.6.0"
+	version             = "0.6.1"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -156,7 +156,6 @@ func main() {
 
 	// Read server from command line.
 	server := getopt.Args()
-	fmt.Println("args:", server)
 	switch count := len(server); {
 	case count == 0:
 		log.Fatal("Please specify a server.")
@@ -1196,7 +1195,7 @@ func checkCertExpiry(c *tls.Conn) {
 	now := time.Now()
 	switch {
 	case time.Until(expiry).Hours() < 336:
-		fmt.Printf("[%sOK%s]", colorYellow, colorReset)
+		fmt.Printf("[%sWARN%s]", colorYellow, colorReset)
 		printTLSVersion(c.ConnectionState().Version)
 		fmt.Printf(" (Cert expires in %d days at %s)\n",
 			int(time.Until(expiry).Hours())/24, expiry.Truncate(time.Second).String())
